bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDDistribution.compute_logpdf
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDDistribution.compute_logpdf